@@ -2,7 +2,6 @@
 from __future__ import annotations
 
 import asyncio
-import base64
 import contextlib
 import json
 import logging
@@ -21,7 +20,7 @@ from qolsys_controller.mqtt_command import (
 )
 
 from .enum import PartitionAlarmState, PartitionArmingType, PartitionSystemStatus
-from .enum_zwave import ThermostatFanMode, ThermostatMode, ZwaveCommand, ZwaveDeviceClass
+from .enum_zwave import ThermostatFanMode, ThermostatMode, ZwaveCommandClass, ZwaveDeviceClass
 from .errors import QolsysMqttError, QolsysSslError, QolsysUserCodeError
 from .mdns import QolsysMDNS
 from .mqtt_command_queue import QolsysMqttCommandQueue
@@ -53,6 +52,7 @@ class QolsysController:
         self.certificate_exchange_server: asyncio.Server | None = None
         self._task_manager = QolsysTaskManager()
         self._mqtt_command_queue = QolsysMqttCommandQueue()
+        self._zone_id: str = "1"
 
         # MQTT Client
         self.aiomqtt: aiomqtt.Client | None = None
@@ -201,14 +201,10 @@ class QolsysController:
                     # Subscribe to MQTT commands send to panel by other devices
                     await self.aiomqtt.subscribe("mastermeid", qos=self.settings.mqtt_qos)
 
-                    # Subscribe to all topics
-                    # await self.aiomqtt.subscribe("#", qos=self.settings.mqtt_qos)
-
                 self._task_manager.run(self.mqtt_listen_task(), self._mqtt_task_listen_label)
                 self._task_manager.run(self.mqtt_ping_task(), self._mqtt_task_ping_label)
 
                 response_connect = await self.command_connect()
-
                 self.panel.imei = response_connect.get("master_imei", "")
                 self.panel.product_type = response_connect.get("primary_product_type", "")
 
@@ -285,14 +281,7 @@ class QolsysController:
                 if message.topic.matches("ZWAVE_RESPONSE"):  # noqa: SIM102
                     if isinstance(message.payload, bytes):
                         data = json.loads(message.payload.decode())
-                        zwave = data.get("ZWAVE_RESPONSE", "")
-                        decoded_payload = base64.b64decode(zwave.get("ZWAVE_PAYLOAD", "")).hex()
-                        LOGGER.debug(
-                            "Z-Wave Response: Node(%s) - Status(%s) - Payload(%s)",
-                            zwave.get("NODE_ID", ""),
-                            zwave.get("ZWAVE_COMMAND_STATUS", ""),
-                            decoded_payload,
-                        )
+                        self.panel.parse_zwave_message(data)
 
         except aiomqtt.MqttError as err:
             self.connected = False
@@ -769,7 +758,7 @@ class QolsysController:
         trigger_command = {
             "operation_name": "generate_emergency",
             "partitionID": int(partition_id),
-            "zoneID": 1,
+            "zoneID": int(self._zone_id),
             "emergencyType": "Silent Police Emergency" if silent else "Police Emergency",
             "operation_source": 1,
             "macAddress": self.settings.random_mac,
@@ -799,7 +788,7 @@ class QolsysController:
         trigger_command = {
             "operation_name": "generate_emergency",
             "partitionID": int(partition_id),
-            "zoneID": 1,
+            "zoneID": int(self._zone_id),
             "emergencyType": "Silent Auxiliary Emergency" if silent else "Auxiliary Emergency",
             "operation_source": 1,
             "macAddress": self.settings.random_mac,
@@ -829,7 +818,7 @@ class QolsysController:
         trigger_command = {
             "operation_name": "generate_emergency",
             "partitionID": int(partition_id),
-            "zoneID": 1,
+            "zoneID": int(self._zone_id),
             "emergencyType": "Fire Emergency",
             "operation_source": 1,
             "macAddress": self.settings.random_mac,
@@ -864,7 +853,7 @@ class QolsysController:
         if status:
             level = 255
 
-        command = MQTTCommand_ZWave(self, node_id, [ZwaveCommand.SwitchBinary, 1, level])
+        command = MQTTCommand_ZWave(self, node_id, [ZwaveCommandClass.SwitchBinary, 1, level])
         response = await command.send_command()
         LOGGER.debug("MQTT: Receiving set_zwave_switch_binary command")
         return response
@@ -881,7 +870,7 @@ class QolsysController:
             LOGGER.error("switch_multilevel_set used on invalid %s", zwave_node.generic_device_type)
             return None
 
-        command = MQTTCommand_ZWave(self, node_id, [ZwaveCommand.SwitchMultilevel, 1, level])
+        command = MQTTCommand_ZWave(self, node_id, [ZwaveCommandClass.SwitchMultilevel, 1, level])
         response = await command.send_command()
         LOGGER.debug("MQTT: Receiving set_zwave_multilevel_switch command")
         return response
@@ -899,7 +888,7 @@ class QolsysController:
         if locked:
             lock_mode = 255
 
-        command = MQTTCommand_ZWave(self, node_id, [ZwaveCommand.DoorLock, 1, lock_mode])
+        command = MQTTCommand_ZWave(self, node_id, [ZwaveCommandClass.DoorLock, 1, lock_mode])
         response = await command.send_command()
         LOGGER.debug("MQTT: Receiving zwave_doorlock_set command")
         return response
@@ -916,7 +905,7 @@ class QolsysController:
             LOGGER.error("thermostat_setpoint_set - Invalid node_id %s", node_id)
             return None
 
-        command = MQTTCommand_ZWave(self, node_id, [ZwaveCommand.ThermostatSetPoint, 1, mode, int(setpoint)])
+        command = MQTTCommand_ZWave(self, node_id, [ZwaveCommandClass.ThermostatSetPoint, 1, mode, int(setpoint)])
         response = await command.send_command()
         LOGGER.debug("MQTT: Receiving zwave_thermostat_mode_set command")
         return response
@@ -924,12 +913,16 @@ class QolsysController:
     async def command_zwave_thermostat_mode_set(self, node_id: str, mode: ThermostatMode) -> dict[str, Any] | None:
         LOGGER.debug("MQTT: Sending zwave_thermostat_mode_set command - Node(%s) - Mode(%s)", node_id, mode)
 
-        zwave_node = self.state.zwave_device(node_id)
-        if not zwave_node:
-            LOGGER.error("thermostat_mode_set - Invalid node_id %s", node_id)
+        thermostat = self.state.zwave_thermostat(node_id)
+        if not thermostat:
+            LOGGER.error("zwave_thermostat_mode_set - Invalid node_id %s", node_id)
             return None
 
-        command = MQTTCommand_ZWave(self, node_id, [ZwaveCommand.ThermostatMode, 1, mode])
+        LOGGER.debug("thermostat_mode: %s", int(mode))
+        if mode not in thermostat.available_thermostat_mode():
+            LOGGER.error("thermostat_mode_set - Invalid mode %s", mode)
+
+        command = MQTTCommand_ZWave(self, node_id, [ZwaveCommandClass.ThermostatMode, 1, int(mode)])
         response = await command.send_command()
         LOGGER.debug("MQTT: Receiving zwave_thermostat_mode_set command")
         return response
@@ -942,7 +935,7 @@ class QolsysController:
             LOGGER.error("thermostat_fan_mode_set - Invalid node_id %s", node_id)
             return None
 
-        command = MQTTCommand_ZWave(self, node_id, [ZwaveCommand.ThermostatFanMode, 1, fan_mode])
+        command = MQTTCommand_ZWave(self, node_id, [ZwaveCommandClass.ThermostatFanMode, 1, fan_mode])
         response = await command.send_command()
         LOGGER.debug("MQTT: Receiving zwave_thermostat_fan_mode_set command")
         return response
