@@ -58,7 +58,7 @@ class ZoneStatus(StrEnum):
     NORMAL = "Normal"
     UNREACHABLE = "Unreachable"
     TAMPERED = "Tampered"
-    SYNCHONIZING = "Synchonizing"
+    SYNCHRONIZING = "Synchronizing"
     CONNECTED = "connected"
     DISCONNECTED = "disconnected"
     FAILURE = "Failure"
@@ -132,6 +132,7 @@ class ZoneSensorGroup(StrEnum):
     STAY_INSTANT_MOTION = "stayinstantmotion"
     STAY_DELAY_MOTION = "staydelaymotion"
     AWAY_DELAY_MOTION = "awaydelaymotion"
+    WATER = "WaterSensor"
 
     # TAKEOVER = "" #TBD
     # GARAGE_TILT_SAFETY = "" # TBD
