@@ -1,9 +1,14 @@
 from __future__ import annotations
 
+import base64
 import json
 import logging
 from typing import TYPE_CHECKING, Any
 
+from qolsys_controller.adc_device import QolsysAdcDevice
+from qolsys_controller.zwave_meter import QolsysMeterDevice
+from qolsys_controller.zwave_thermometer import QolsysThermometer
+
 from .database.db import QolsysDB
 from .enum import (
     PartitionAlarmState,
@@ -386,9 +391,54 @@ class QolsysPanel(QolsysObservable):
         self._controller.state.sync_partitions_data(self.get_partitions_from_db())
         self._controller.state.sync_zones_data(self.get_zones_from_db())
         self._controller.state.sync_zwave_devices_data(self.get_zwave_devices_from_db())
+        self._controller.state.sync_adc_devices_data(self.get_adc_devices_from_db())
         self._controller.state.sync_scenes_data(self.get_scenes_from_db())
         self._controller.state.sync_weather_data(self.get_weather_from_db())
 
+        # Validate all local user match a Qolsys Panel user
+        qolsys_users = self.db.get_users()
+        qolsys_user_list = []
+        for qolsys_user in qolsys_users:
+            try:
+                userid = int(qolsys_user.get("userid", ""))
+            except ValueError:
+                LOGGER.error("Invalid userid in panel database: %s", qolsys_user.get("userid", ""))
+                userid = -1
+
+            qolsys_user_list.append(userid)
+
+        for local_user in self._users:
+            if local_user.id not in qolsys_user_list:
+                LOGGER.error("ID %s from users.conf file not found in panel database", local_user.id)
+
+        # Check associated zone_id in iqremotesettins table
+        LOGGER.debug("Checking iqremotesettings table for zone_id matching panel MAC address")
+        iqremote_settings_list = self.db.get_iqremote_settings()
+        for iqremote in iqremote_settings_list:
+            if (
+                self._controller.settings.random_mac.replace(":", "").lower()
+                == iqremote.get("mac_address", "").replace(":", "").lower()
+            ):
+                self._controller._zone_id = iqremote.get("zone_id", "")
+                LOGGER.debug("Found matching zone_id: %s", self._controller._zone_id)
+                break
+
+    # Parse Z-Wave message
+    def parse_zwave_message(self, data: dict[str, Any]) -> None:
+        zwave = data.get("ZWAVE_RESPONSE", "")
+        payload = base64.b64decode(zwave.get("ZWAVE_PAYLOAD", "")).hex()
+        LOGGER.debug(
+            "Z-Wave Response: Node(%s) - Status(%s) - Payload(%s)",
+            zwave.get("NODE_ID", ""),
+            zwave.get("ZWAVE_COMMAND_STATUS", ""),
+            payload,
+        )
+
+        node_id: str = str(zwave.get("NODE_ID", 0))
+        node = self._controller.state.zwave_device(node_id)
+        if node is not None:
+            node.update_raw(bytes.fromhex(payload))
+
     # Parse panel update to database
     def parse_iq2meid_message(self, data: dict[str, Any]) -> None:  # noqa: C901, PLR0912, PLR0915
         eventName = data.get("eventName")
@@ -564,10 +614,22 @@ class QolsysPanel(QolsysObservable):
                             case self.db.table_zwave_association_goup.uri:
                                 self.db.table_zwave_association_goup.update(selection, selection_argument, content_values)
 
+                            # Update Zwave Other
+                            case self.db.table_zwave_other.uri:
+                                self.db.table_zwave_other.update(selection, selection_argument, content_values)
+
                             # Country Locale
                             case self.db.table_country_locale.uri:
                                 self.db.table_country_locale.update(selection, selection_argument, content_values)
 
+                            # Virtual device
+                            case self.db.table_virtual_device.uri:
+                                self.db.table_virtual_device.update(selection, selection_argument, content_values)
+                                adc_id = content_values.get("device_id", "")
+                                adc_device = self._controller.state.adc_device(adc_id)
+                                if adc_device is not None:
+                                    adc_device.update_adc_device(content_values)
+
                             case _:
                                 LOGGER.debug("iq2meid updating unknow uri:%s", uri)
                                 LOGGER.debug(data)
@@ -645,6 +707,13 @@ class QolsysPanel(QolsysObservable):
                             case self.db.table_zwave_association_goup.uri:
                                 self.db.table_zwave_association_goup.delete(selection, selection_argument)
 
+                            case self.db.table_virtual_device.uri:
+                                self.db.table_virtual_device.delete(selection, selection_argument)
+                                self._controller.state.sync_adc_devices_data(self.get_adc_devices_from_db())
+
+                            case self.db.table_zwave_other.uri:
+                                self.db.table_zwave_other.delete(selection, selection_argument)
+
                             case _:
                                 LOGGER.debug("iq2meid deleting unknown uri:%s", uri)
                                 LOGGER.debug(data)
@@ -775,9 +844,21 @@ class QolsysPanel(QolsysObservable):
                                 self.db.table_weather.insert(data=content_values)
                                 self._controller.state.sync_weather_data(self.get_weather_from_db())
 
+                            # ZWave Association Group
                             case self.db.table_zwave_association_goup.uri:
                                 self.db.table_zwave_association_goup.insert(data=content_values)
 
+                            # Zwave Other
+                            case self.db.table_zwave_other.uri:
+                                self.db.table_zwave_other.insert(data=content_values)
+                                LOGGER.debug("New Z-Wave Other information")
+                                LOGGER.debug(content_values)
+
+                            # Virtual Device
+                            case self.db.table_virtual_device.uri:
+                                self.db.table_virtual_device.insert(data=content_values)
+                                self._controller.state.sync_adc_devices_data(self.get_adc_devices_from_db())
+
                             case _:
                                 LOGGER.debug("iq2meid inserting unknow uri:%s", uri)
                                 LOGGER.debug(data)
@@ -797,6 +878,15 @@ class QolsysPanel(QolsysObservable):
         # No valid user code found
         return -1
 
+    def get_adc_devices_from_db(self) -> list[QolsysAdcDevice]:
+        adc_devices: list[QolsysAdcDevice] = []
+        devices_list = self.db.get_adc_devices()
+
+        for device in devices_list:
+            adc_devices.append(QolsysAdcDevice(device))
+
+        return adc_devices
+
     def get_zwave_devices_from_db(self) -> list[QolsysZWaveDevice]:
         devices: list[QolsysZWaveDevice] = []
         devices_list = self.db.get_zwave_devices()
@@ -806,8 +896,21 @@ class QolsysPanel(QolsysObservable):
 
         for device in devices_list:
             device_added = False
-
             zwave_node_id = device.get("node_id", "")
+
+            # Check if z-wave device is an Energy Clamp
+            if device.get("node_type", "") == "Energy Clamp":
+                qolsys_meter_device = QolsysMeterDevice(device)
+                qolsys_meter_device.create_generic_electric_meter()
+                devices.append(qolsys_meter_device)
+                device_added = True
+
+            # Check if z-wave device is a thermometer
+            if device.get("node_type", "") == "Thermometer":
+                qolsys_thermometer = QolsysThermometer(device)
+                devices.append(qolsys_thermometer)
+                device_added = True
+
             # Check if z-wave device is a Dimmer
             for d in dimmers_list:
                 dimmer_node_id = d.get("node_id", "")
