@@ -1,8 +1,15 @@
 from __future__ import annotations
 
 import logging
+from enum import IntEnum
 from typing import TYPE_CHECKING
 
+from qolsys_controller.adc_service import QolsysAdcService
+from qolsys_controller.adc_service_garagedoor import QolsysAdcGarageDoorService
+from qolsys_controller.zwave_meter import QolsysMeterDevice
+from qolsys_controller.zwave_thermometer import QolsysThermometer
+
+from .adc_device import QolsysAdcDevice
 from .observable import QolsysObservable
 from .weather import QolsysWeather
 from .zwave_device import QolsysZWaveDevice
@@ -28,11 +35,14 @@ class QolsysState(QolsysObservable):
         self._weather: QolsysWeather = QolsysWeather()
         self._partitions: list[QolsysPartition] = []
         self._zones: list[QolsysZone] = []
+        self._adc_devices: list[QolsysAdcDevice] = []
         self._zwave_devices: list[QolsysZWaveDevice] = []
         self._scenes: list[QolsysScene] = []
+
         self._state_partition_observer = QolsysObservable()
         self._state_zone_observer = QolsysObservable()
         self._state_zwave_observer = QolsysObservable()
+        self._state_adc_observer = QolsysObservable()
         self._state_scene_observer = QolsysObservable()
 
     @property
@@ -43,6 +53,10 @@ class QolsysState(QolsysObservable):
     def zwave_devices(self) -> list[QolsysZWaveDevice]:
         return self._zwave_devices
 
+    @property
+    def adc_devices(self) -> list[QolsysAdcDevice]:
+        return self._adc_devices
+
     @property
     def zones(self) -> list[QolsysZone]:
         return self._zones
@@ -79,9 +93,28 @@ class QolsysState(QolsysObservable):
         for device in self.zwave_devices:
             if isinstance(device, QolsysThermostat):
                 thermostats.append(device)
-
         return thermostats
 
+    @property
+    def zwave_meters(self) -> list[QolsysMeterDevice]:
+        meters = []
+        for device in self.zwave_devices:
+            if isinstance(device, QolsysMeterDevice):
+                meters.append(device)
+        return meters
+
+    @property
+    def zwave_thermometers(self) -> list[QolsysThermometer]:
+        thermometer = []
+        for device in self.zwave_devices:
+            if isinstance(device, QolsysThermometer):
+                thermometer.append(device)
+        return thermometer
+
+    @property
+    def zwave_other_devices(self) -> list[dict[str, str]]:
+        return self._controller.panel.db.get_zwave_other_devices()
+
     @property
     def state_partition_observer(self) -> QolsysObservable:
         return self._state_partition_observer
@@ -98,6 +131,10 @@ class QolsysState(QolsysObservable):
     def state_scene_observer(self) -> QolsysObservable:
         return self._state_scene_observer
 
+    @property
+    def state_adc_observer(self) -> QolsysObservable:
+        return self._state_adc_observer
+
     def partition(self, partition_id: str) -> QolsysPartition | None:
         for partition in self.partitions:
             if partition.id == partition_id:
@@ -195,7 +232,12 @@ class QolsysState(QolsysObservable):
         for zwave_device in self.zwave_devices:
             if zwave_device.node_id == node_id:
                 return zwave_device
+        return None
 
+    def zwave_thermostat(self, node_id: str) -> QolsysThermostat | None:
+        thermostat = self.zwave_device(node_id)
+        if isinstance(thermostat, QolsysThermostat):
+            return thermostat
         return None
 
     def zwave_add(self, new_zwave: QolsysZWaveDevice) -> None:
@@ -220,6 +262,61 @@ class QolsysState(QolsysObservable):
         self.zwave_devices.remove(zwave)
         self.state_zwave_observer.notify()
 
+    def adc_device(self, device_id: str) -> QolsysAdcDevice | None:
+        for adc_device in self.adc_devices:
+            if adc_device.device_id == device_id:
+                return adc_device
+        return None
+
+    def adc_add(self, new_adc: QolsysAdcDevice) -> None:
+        for adc_device in self.adc_devices:
+            if new_adc.device_id == adc_device.device_id:
+                LOGGER.debug("Adding ADC to State, ADC%s (%s) - Allready in ADC List", new_adc.device_id, new_adc.name)
+                return
+
+        self.adc_devices.append(new_adc)
+        self.adc_devices.sort(key=lambda x: x.device_id, reverse=False)
+        self.state_adc_observer.notify()
+
+    def adc_delete(self, device_id: str) -> None:
+        adc = self.adc_device(device_id)
+
+        if adc is None:
+            LOGGER.debug("Deleting ADC from State, ADC%s not found", device_id)
+            return
+
+        self.adc_devices.remove(adc)
+        self.state_adc_observer.notify()
+
+    def sync_adc_devices_data(self, db_adcs: list[QolsysAdcDevice]) -> None:
+        db_adc_list = []
+        for db_adc in db_adcs:
+            db_adc_list.append(db_adc.device_id)
+
+        state_adc_list = []
+        for state_adc in self.adc_devices:
+            state_adc_list.append(state_adc.device_id)
+
+        # Update existing ADC devices
+        for state_adc in self.adc_devices:
+            if state_adc.device_id in db_adc_list:
+                for db_adc in db_adcs:
+                    if state_adc.device_id == db_adc.device_id:
+                        LOGGER.debug("sync_data - update ADC%s", state_adc.device_id)
+                        state_adc.update_adc_device(db_adc.to_dict_adc())
+
+        # Add new ADC devices
+        for db_adc in db_adcs:
+            if db_adc.device_id not in state_adc_list:
+                LOGGER.debug("sync_data - add ADC%s", db_adc.device_id)
+                self.adc_add(db_adc)
+
+        # Delete ADC device
+        for state_adc in self.adc_devices:
+            if state_adc.device_id not in db_adc_list:
+                LOGGER.debug("sync_data - delete ADC%s", state_adc.device_id)
+                self.adc_delete(state_adc.device_id)
+
     def sync_zwave_devices_data(self, db_zwaves: list[QolsysZWaveDevice]) -> None:  # noqa: PLR0912
         db_zwave_list = []
         for db_zwave in db_zwaves:
@@ -254,6 +351,12 @@ class QolsysState(QolsysObservable):
                             state_zwave.update_lock(db_zwave.to_dict_lock())
                             break
 
+                        # Update Meter
+                        if isinstance(state_zwave, QolsysMeterDevice) and isinstance(db_zwave, QolsysMeterDevice):
+                            # Meter state not store in database
+                            # Keep old value instact
+                            break
+
                         # Generic Z-Wave Device
                         if isinstance(state_zwave, QolsysGeneric) and isinstance(db_zwave, QolsysGeneric):
                             state_zwave.update_base(db_zwave.to_dict_base())
@@ -430,6 +533,27 @@ class QolsysState(QolsysObservable):
                 LOGGER.debug("Lock%s (%s) - lock_status: %s", zid, name, zwave.lock_status)
                 continue
 
+            if isinstance(zwave, QolsysMeterDevice):
+                nid = zwave.node_id
+                name = zwave.node_name
+                LOGGER.debug("Meter%s (%s)", nid, name)
+
+                for meter_sensor in zwave.meters:
+                    scale_type: type[IntEnum] = zwave.scale_for_meter_type(meter_sensor.meter_type)
+
+                    LOGGER.debug(
+                        " Sensor%s (%s) - value: %s (%s)",
+                        meter_sensor.meter_type,
+                        meter_sensor.meter_type.name,
+                        meter_sensor.value,
+                        scale_type(meter_sensor.scale).name,
+                    )
+
+            if isinstance(zwave, QolsysThermometer):
+                nid = zwave.node_id
+                name = zwave.node_name
+                LOGGER.debug("Thermometer%s (%s)", nid, name)
+
             if isinstance(zwave, QolsysGeneric):
                 zid = zwave.node_id
                 name = zwave.node_name
@@ -439,6 +563,20 @@ class QolsysState(QolsysObservable):
                 LOGGER.debug("Generic%s (%s) - battery_level_vale: %s", zid, name, zwave.node_battery_level_value)
                 continue
 
+        LOGGER.debug("Other Z-Wave devices information")
+        LOGGER.debug(self.zwave_other_devices)
+
+        for adc in self.adc_devices:
+            for service in adc.services:
+                if isinstance(service, QolsysAdcGarageDoorService):
+                    LOGGER.debug(
+                        "ADC%s GarageDoor%s (%s) - state: %s", adc.device_id, service.id, adc.name, service.func_state
+                    )
+                    continue
+
+                if isinstance(service, QolsysAdcService):
+                    LOGGER.debug("ADC%s Service%s (%s) - state: %s", adc.device_id, service.id, adc.name, service.func_state)
+
         for scene in self.scenes:
             sid = scene.scene_id
             name = scene.name
