@@ -36,6 +36,9 @@ class QolsysZWaveDevice(QolsysObservable):
         self._last_updated_date: str = zwave_dict.get("last_updated_date", "")
         self._command_class_list: str = zwave_dict.get("command_class_list", "")
 
+    def update_raw(self, payload: bytes) -> None:
+        LOGGER.debug("Raw Update (node%s) - payload: %s", self.node_id, payload.hex())
+
     def update_base(self, data: dict[str, str]) -> None:  # noqa: C901, PLR0912, PLR0915
         # Check if we are updating same node_id
         node_id_update = data.get("node_id", "")
@@ -136,8 +139,16 @@ class QolsysZWaveDevice(QolsysObservable):
             self.notify()
 
     @property
-    def node_battery_level_value(self) -> str:
-        return self._node_battery_level_value
+    def node_battery_level_value(self) -> int | None:
+        try:
+            value = int(self._node_battery_level_value)
+            if value >= 0 and value <= 100:
+                return value
+            else:
+                return None
+
+        except ValueError:
+            return None
 
     @node_battery_level_value.setter
     def node_battery_level_value(self, value: str) -> None:
@@ -197,6 +208,9 @@ class QolsysZWaveDevice(QolsysObservable):
         except ValueError:
             return ZwaveDeviceClass.Unknown
 
+    def is_battery_enabled(self) -> bool:
+        return self.node_battery_level_value is not None
+
     def to_dict_base(self) -> dict[str, str]:
         return {
             "_id": self._id,
@@ -206,7 +220,7 @@ class QolsysZWaveDevice(QolsysObservable):
             "node_status": self.node_status,
             "partition_id": self._partition_id,
             "node_battery_level": self.node_battery_level,
-            "node_battery_level_value": self.node_battery_level_value,
+            "node_battery_level_value": self._node_battery_level_value,
             "paired_status": self.paired_status,
             "node_secure_cmd_cls": self._node_secure_cmd_cls,
             "is_node_listening_node": self._is_node_listening_node,
