@@ -42,6 +42,11 @@ class QolsysThermostat(QolsysZWaveDevice):
         self._thermostat_paired_status: str = thermostat_dict.get("paired_status", "")
         self._thermostat_configuration_parameter: str = thermostat_dict.get("configuration_parameter", "")
 
+        LOGGER.debug("Thermostat%s", self._thermostat_node_id)
+        LOGGER.debug("Thermostat Mode: %s", self.available_thermostat_mode())
+        LOGGER.debug("Thermostat Fan Mode: %s", self.available_thermostat_fan_mode())
+        LOGGER.debug("Thermostat Set Point Mode: %s", self.available_thermostat_set_point_mode())
+
     # -----------------------------
     # properties + setters
     # -----------------------------
@@ -118,11 +123,31 @@ class QolsysThermostat(QolsysZWaveDevice):
 
     @property
     def thermostat_mode(self) -> ThermostatMode | None:
-        thermostat_mode = int(self._thermostat_mode)
-        for mode in ThermostatMode:
-            if thermostat_mode == mode:
-                return mode
-        return None
+        value = self._thermostat_mode.strip("[]").split(",")
+
+        if len(value) > 1:
+            LOGGER.error(
+                "Thermostat%s (%s) - thermostat_mode has multiple values: %s",
+                self.thermostat_node_id,
+                self.thermostat_name,
+                value,
+            )
+            return None
+
+        try:
+            int_value = int(value[0])
+            for mode in ThermostatMode:
+                if int_value == mode.value:
+                    return mode
+            return None
+        except ValueError:
+            LOGGER.error(
+                "Thermostat%s (%s) - thermostat_mode value is not an integer: %s",
+                self.thermostat_node_id,
+                self.thermostat_name,
+                value,
+            )
+            return None
 
     @thermostat_mode.setter
     def thermostat_mode(self, value: str) -> None:
@@ -133,11 +158,31 @@ class QolsysThermostat(QolsysZWaveDevice):
 
     @property
     def thermostat_fan_mode(self) -> ThermostatFanMode | None:
-        thermostat_fan_mode = int(self._thermostat_fan_mode)
-        for mode in ThermostatFanMode:
-            if thermostat_fan_mode == mode:
-                return mode
-        return None
+        value = self._thermostat_fan_mode.strip("[]").split(",")
+
+        if len(value) > 1:
+            LOGGER.error(
+                "Thermostat%s (%s) - thermostat_fan_mode has multiple values: %s",
+                self.thermostat_node_id,
+                self.thermostat_name,
+                value,
+            )
+            return None
+
+        try:
+            int_value = int(value[0])
+            for mode in ThermostatFanMode:
+                if int_value == mode.value:
+                    return mode
+            return None
+        except ValueError:
+            LOGGER.error(
+                "Thermostat%s (%s) - thermostat_fan_mode value is not an integer: %s",
+                self.thermostat_node_id,
+                self.thermostat_name,
+                value,
+            )
+            return None
 
     @thermostat_fan_mode.setter
     def thermostat_fan_mode(self, value: str) -> None:
@@ -148,7 +193,7 @@ class QolsysThermostat(QolsysZWaveDevice):
 
     @property
     def thermostat_set_point_mode(self) -> str:
-        return self._thermostat_set_point_mode
+        return self._thermostat_set_point_mode.strip("[]")
 
     @thermostat_set_point_mode.setter
     def thermostat_set_point_mode(self, value: str) -> None:
@@ -157,6 +202,9 @@ class QolsysThermostat(QolsysZWaveDevice):
             self._thermostat_set_point_mode = value
             self.notify()
 
+    def update_raw(self, payload: bytes) -> None:
+        pass
+
     def update_thermostat(self, data: dict[str, str]) -> None:  # noqa: C901, PLR0912, PLR0915
         # Check if we are updating same none_id
         node_id_update = data.get("node_id", "")
@@ -237,6 +285,7 @@ class QolsysThermostat(QolsysZWaveDevice):
             "opr": self._thermostat_opr,
             "partition_id": self._thermostat_partition_id,
             "thermostat_name": self.thermostat_name,
+            "node_id": self.thermostat_node_id,
             "device_temp_unit": self.thermostat_device_temp_unit,
             "current_temp": self.thermostat_current_temp,
             "target_cool_temp": self.thermostat_target_cool_temp,
@@ -264,7 +313,7 @@ class QolsysThermostat(QolsysZWaveDevice):
         }
 
     def available_thermostat_mode(self) -> list[ThermostatMode]:
-        int_list = [int(x) for x in self._thermostat_mode_bitmask.split(",")]
+        int_list = [int(x) for x in self._thermostat_mode_bitmask.strip("[]").split(",")]
         byte_array = bytes(int_list)
         bitmask = int.from_bytes(byte_array, byteorder="little")
 
@@ -276,7 +325,7 @@ class QolsysThermostat(QolsysZWaveDevice):
         return mode_array
 
     def available_thermostat_fan_mode(self) -> list[ThermostatFanMode]:
-        int_list = [int(x) for x in self._thermostat_fan_mode_bitmask.split(",")]
+        int_list = [int(x) for x in self._thermostat_fan_mode_bitmask.strip("[]").split(",")]
         byte_array = bytes(int_list)
         bitmask = int.from_bytes(byte_array, byteorder="little")
 
@@ -288,7 +337,7 @@ class QolsysThermostat(QolsysZWaveDevice):
         return fan_mode_array
 
     def available_thermostat_set_point_mode(self) -> list[ThermostatMode]:
-        int_list = [int(x) for x in self._thermostat_set_point_mode_bitmask.split(",")]
+        int_list = [int(x) for x in self._thermostat_set_point_mode_bitmask.strip("[]").split(",")]
         byte_array = bytes(int_list)
         bitmask = int.from_bytes(byte_array, byteorder="little")
 
